========================
 inspire-crawler v0.2.2
========================

inspire-crawler v0.2.2 was released on 6th of July, 2016.

About
-----

Crawler integration with INSPIRE-HEP using scrapy project `HEPCrawl`_.


What's new
----------

- Added CrawlerWorkflowObject to models
- Updates to support new invenio-workflows

Installation
------------

   $ pip install inspire-crawler==0.2.2

Documentation
-------------

   http://pythonhosted.org/inspire-crawler/

Good luck and thanks for choosing inspire-crawler.

| INSPIRE Development Team
|   Email: feedback@inspirehep.net
|   Twitter: http://twitter.com/inspirehep
|   GitHub: http://github.com/inspirehep
|   URL: http://inspirehep.net
